@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: FWObject.cpp,v 1.2 2004/09/08 05:34:50 vkurland Exp $
+  $Id: FWObject.cpp,v 1.5 2005/03/31 05:49:40 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -126,11 +126,9 @@ xmlNodePtr FWObject::toXML(xmlNodePtr parent, bool process_children) throw(FWExc
     {
         const string &name  = (*i).first;
         const string &value = (*i).second;
-
         xmlAttrPtr pr = xmlNewProp(me, 
-                                   STRTOXMLCAST(name) , 
-                                   STRTOXMLCAST((name=="comment"?XMLTools::quote_linefeeds(value):value)));
-        
+                                   STRTOXMLCAST(name),
+                                   STRTOXMLCAST(value));
         if(name=="id")
         {
             xmlAddID(NULL, parent->doc, STRTOXMLCAST(value), pr);
@@ -723,6 +721,8 @@ void FWObject::_removeAll(FWObject *rm)
 
 void FWObject::removeAllInstances(FWObject *rm)
 {
+    checkReadOnly();
+
     bool deletedObject =
         (rm->getParent()->getId()==FWObjectDatabase::getDeletedObjectsId());
 
@@ -780,15 +780,15 @@ void FWObject::removeRef(FWObject *obj)
 
 void FWObject::_removeAllRef(FWObject *rm)
 {
-	for (FWObject::iterator i=begin(); i!=end(); i++)
-		(*i)->_removeAllRef(rm);
-
-	removeRef(rm);
+    for (FWObject::iterator i=begin(); i!=end(); i++)
+        (*i)->_removeAllRef(rm);
+    
+    removeRef(rm);
 }
 
 void FWObject::removeAllReferences(FWObject *rm)
 {
-	_removeAllRef(rm);
+    _removeAllRef(rm);
 //    std::for_each(begin(), end(), RemoveReference(obj) );
 }
 
